Learn R Programming

lipidomeR (version 0.1.2)

cancerlipidome: Levels of lipids in benign and malignant breast tumors in humans.

Description

This data set contains levels of 409 named lipids in 118 human breast tumor tissue samples.

Usage

data( cancerlipidome )

Arguments

Format

A long-format data frame with 48262 rows and 7 variables:

ID

Participant number

Group

Diagnosis of the type tumor: benign, cancer, or metastasis

Race

Ethnic background of the participant

Stage

Diagnosis of the stage of the tumor

Type

Sub-type of the breast tumor. IDC: Invasive Ductal Carcinoma

Lipid_Name

Name of the lipid. The names are in the format 'XY(C:D)', where 'XY' is the abbreviation of the lipid class, 'C' is the total number of carbon atoms in the fatty-acid chains, and 'D' is the total number of double-bonds in the fatty acid chains.

Lipid_Level

Measured level of the lipid.

References

Purwaha, P., et al. Unbiased lipidomic profiling of triple-negative breast cancer tissues reveals the association of sphingomyelin levels with patient disease-free survival. Metabolites 8, 41 (2018) (doi: 10.3390/metabo8030041)

Examples

Run this code
# NOT RUN {
# Import the data set.
data( cancerlipidome )
# }
# NOT RUN {
# Convert the data into wide format, where each lipid is one column and
# each sample is one row.
cancerlipidome.wide <-
   tidyr::pivot_wider(
       data = cancerlipidome,
       names_from = Lipid_Name,
       values_from = Lipid_Level
   )
# Inspect the data frame.
# View( cancerlipidome.wide )
# Create a mapping of the lipid names.
names.mapping <-
   map_lipid_names( x = unique( cancerlipidome$"Lipid_Name" ) )
# Compute the regression models.
result.limma <-
   compute_models_with_limma(
       x = cancerlipidome.wide,
       dependent.variables = names.mapping$"Name",
       independent.variables = c( "Group" )
   )
# }
# NOT RUN {
# Create a figure of all lipids and factors.
figure.output <-
  heatmap_lipidome_from_limma(
    x = result.limma$"model",
    names.mapping = names.mapping,
    axis.x.carbons = FALSE,
    class.facet = "row",
    plot.all = TRUE,
    plot.individual = FALSE,
    print.figure = TRUE,
    scales = "free",
    space = "free"
  )
# }
# NOT RUN {
# Create individual figures for each factor.
figure.output <-
   heatmap_lipidome_from_limma(
       x = result.limma$"model",
       names.mapping = names.mapping,
       axis.x.carbons = FALSE,
       class.facet = "wrap",
       omit.class = "PA",
       plot.all = FALSE,
       plot.individual = TRUE,
       print.figure = FALSE,
       scales = "free",
       space = "free"
   )
# Print the figure of differences between cancer and benign tumors.
print( figure.output[[ "GroupCancer" ]] )

# }

Run the code above in your browser using DataLab