Use this to achieve analysis of variance (ANOVA) or analysis of covariance
(ANCOVA). The F-test is based on a model produced by the function
compute_models_with_limma.
To use this function, first call the function
compute_models_with_limma.
compute_F_test_with_limma(x, p.adj.threshold = 0.05, print.table = FALSE)(Required) list of models for which the test will be done.
The F-test will be computed for the first independent variable that was
specified in the independent.variables argument to the
function compute_models_with_limma.
(Optional) numeric value specifying the threshold for statistical significance of difference after correction for multiple testing.
(Optional) TRUE or FALSE: Print the results
of the test?
List x supplemented by the results of the F-test.
compute_models_with_limma for the model computation
step that is required prior to calling this function.
compute_post_hoc_test_with_limma for the pairwise
post-hoc comparisons that may follow the F-test done with this function.