Use this function to computing multiple regression models that can be directly supplied to the visualization functions of the 'lipidomeR'.
compute_models_with_limma(
x,
dependent.variables,
independent.variables,
random.effect = NULL,
formula = NULL,
F.test = FALSE,
print.table1 = FALSE,
scale.dependent.variables = TRUE,
scale.independent.variables = FALSE,
verbose = TRUE
)(Required) data matrix.
(Required) vector of names of dependent variables. These should be the names of the lipids.
(Required) vector of names of the independent variables. These should be the names of the variables defining the experiment design.
(Optional) name of a single variable specifying
the random effect for a random-effects model.
For instance, ID specifies a random effect as in
limma::duplicateCorrelation( ..., block = x$'ID' ).
(Optional) character string of model formula in the format accepted by
the function model.matrix and starting with ~.
Variables mentioned in the formula should be included in
the independent.variables argument.
For instance, Group * Treatment.
(Optional) TRUE or FALSE:
Should an F-test for analysis of variance (ANOVA) or
analysis of covariance (ANCOVA) be computed?
(Optional) TRUE or FALSE:
Should a summary table of the independent variables be printed?
(Optional) TRUE or FALSE:
Should dependent variables be scaled to zero-mean and unit-variance
prior to model fitting?
(Optional) TRUE or FALSE:
Should independent variables be scaled to zero-mean and unit-variance
prior to model fitting?
(Optional) TRUE or FALSE: Print messages from
the model fitting?
List of regression results the that can be directly supplied as
an argument to the function heatmap_lipidome_from_limma and
other visualization functions of the lipidomeR.
heatmap_lipidome_from_limma for visualizing the
output of this function.