Use this function to create a heatmap of any lipid-specific values.
Note: Use the function heatmap_lipidome_from_limma to create
heatmaps of model statistics.
heatmap_lipidome(
x,
names.mapping,
axis.x.carbons = TRUE,
class.facet = "row",
fill.direction = "increasing",
fill.limits = c(0, 40),
fill.midpoint = 20,
melt.value.name = "CV",
melt.variable.name = NULL,
melt.x = TRUE,
range.min.N.carbons = 5,
range.min.N.double.bonds = 5,
scale.fill.log = NULL,
scales = "free_y",
space = "free",
x.names = "row.names",
x.variables = NULL
)(Required) named vector of numeric values to create a figure of.
Names need to match to the argument names.mapping through
the function map_lipid_names. Alternatively, a data frame
can be supplied. In that case, set melt.x = TRUE.
(Required) mapping of lipid names from
the map_lipid_names function.
(Optional) TRUE or FALSE: Should
the lipid size (i.e., number of carbon atoms in the fatty acid chain) be
presented on the x-axis or y-axis?
(Optional) character string with possible values
'col', 'row' or 'wrap':
Present lipid classes as panels organized into columns, rows or into a
wrapped layout spanning over multiple rows and columns. The alternative
'wrap' is only available with plot.infividual = TRUE.
(Optional) TRUE or FALSE: Should color
fill be in an increasing direction?
(Optional) numeric vector of length two, indicating the limits of the fill scale.
(Optional) numeric value specifying the midpoint of the fill scale.
(Optional) character string, specifying the name of the variable that will be shown as fill in the heatmap.
(Optional) character string, specifying the name of of the variable that will be used to creating faceted sub-heatmaps.
(Optional) TRUE or FALSE: Should the argument
x be molten by the function melt
prior to plotting? Set melt.x = TRUE, if you want to plot a data
frame instead of a vector of values. In that case, each column of the
data frame will be plotted as an individual facet.
(Optional) numeric value to specify the minimum range of the axis showing the lipid size (number of carbon atoms in the fatty acid chains). This value can be increased from the default value to improve readability in situtions, where there are lipid classes with little or no variation in the lipid size.
(Optional) numeric value to specify the minimum range of the axis showing the lipid saturation (number of double bonds in the fatty acid chains). This value can be increased from the default value to improve readability in situtions, where there are lipid classes with little or no variation in the lipid saturation.
(Optional) numeric value specifying the base of the logarithm, which will be used to creating a logarithmic scale for the fill scale of the plot.
(Optional) character string with possible values
'fixed', 'free', 'free_x' or 'free_y'. This
argument specifies, whether the axes in multiple sub-heatmaps will be in
the same scale ('fixed') or in a scale specific to each sub-figure.
See the function facet_grid for details.
(Optional) character string with possible values
'fixed', 'free', 'free_x' or 'free_y'.
This argument specifies, whether the sub-heatmaps will be of identical
size ('fixed') or not.
(Optional) character string specifying the name of the
variable in the argument x, which will be used to matching
the values to the argument names.mapping.
Use this argument only together with melt.x = TRUE.
(Optional) character vector specifying the names of
the variables, which will be included as individual facets in
the figure.
Use this argument only together with melt.x = TRUE.